@@ -7,7 +7,7 @@ from django.forms import ChoiceField
 from data.models.models import Calibration, Hardware, Accessory, Channel, HardwareConfig, \
     CalibrationConstants, DHT22, MCP3008, \
     ModProbe, PiPico, VEML7700, HardwareChannelTypes, Hub, Category, AccessoryType, SPIIo, SerialIo, PwmIo, I2cIo, \
-    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, PiPicoACAnalogIo, HardwareIO, PMSA0031
+    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, PiPicoACAnalogIo, HardwareIO, PMSA0031, CalibrationStats
 
 
 class HubForm(forms.ModelForm):
@@ -71,6 +71,24 @@ class CalibrationForm(forms.ModelForm):
         model = Calibration
         fields = ("__all__")
 
+class ChannelStatsForm(forms.ModelForm):
+
+    def __init__(self, *args, **kwargs):
+        super(ChannelStatsForm, self).__init__(*args, **kwargs)
+        ## add a "form-control" class to each form input
+        ## for enabling bootstrap
+
+        for name in self.fields.keys():
+            if name == 'calibration':
+                self.fields[name].widget = forms.HiddenInput()
+            self.fields[name].widget.attrs.update({
+                'class': 'form-control',
+            })
+
+    class Meta:
+        model = ChannelStats
+        fields = ('type','value')
+
 
 class HardwareForm(forms.ModelForm):
 
@@ -689,7 +707,6 @@ class DataTransform(forms.ModelForm):
         forms = '<div class="row"><div class="col-6">'
 
         forms = forms + super(DataTransform, self).as_p()
-        forms = forms + '</div><div class="col-6">'
 
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
             forms = forms + '\n  -' + self.nested_constants_form.as_p()
@@ -698,6 +715,7 @@ class DataTransform(forms.ModelForm):
         # if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
         #     forms = forms + '\n  -' + self.nested_hardware_stats_form.as_p()
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            forms = forms + '</div><div class="col-6">'
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
             forms = forms + '\n       -' + self.nested_data_transformer_form.as_p()
         forms = forms + '</div></div>'
@@ -850,7 +868,7 @@ class DataTransformRoot(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)},{'data_transformer': str(self.instance.id)}]
 
         )
-        self.nested_constants_form.extra = self.instance.data_transformer_constants.count()
+        self.nested_constants_form.extra = 0
 
         # hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         # self.nested_hardware_outputs_form = HardwareTransformerForm(
@@ -878,7 +896,6 @@ class DataTransformRoot(forms.ModelForm):
         forms = '<div class="row"><div class="col-6">'
 
         forms = forms + super(DataTransformRoot, self).as_p()
-        forms = forms + '</div><div class="col-6">'
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
             forms = forms + '\n  -' + self.nested_constants_form.as_p()
         # if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
@@ -886,6 +903,7 @@ class DataTransformRoot(forms.ModelForm):
         # if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
         #     forms = forms + '\n  -' + self.nested_hardware_stats_form.as_p()
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            forms = forms + '</div><div class="col-6">'
             print('netdatatransform with number elements: ' + str(len(self.nested_data_transformer_form)))
             forms = forms + '\n       -' + self.nested_data_transformer_form.as_p()
         forms = forms + '</div></div>'
