@@ -17,11 +17,11 @@ from data.forms.forms import HardwareForm, HardwareDHT22Form, HardwareMCP3008For
     HardwarePiPicoForm, HardwareVEML7700Form, HardwareTypeForm, ChannelForm, HardwareConfigForm, AccessoryForm, \
     CalibrationForm, CalibrationConstantForm, HubForm, HardwareIOTypeForm, SPIIoForm, PwmIoForm, SerialIoForm, \
     I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoACAnalogIoForm, PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm, \
-    HardwarePMSA0031Form
+    HardwarePMSA0031Form,ChannelStatsForm
 from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7700, Accessory, Calibration, \
-    CalibrationConstants, Channel, Hub, HardwareIO
+    CalibrationConstants, Channel, Hub, HardwareIO, ChannelStats
 from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
-    CalibrationSerializer, HubSerializer, HardwareIOSerializer
+    CalibrationSerializer, HubSerializer, HardwareIOSerializer, ChannelStatsSerializer
 
 SPI = 'SPI'
 Serial = 'Serial'
@@ -437,7 +437,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         print('post data transformer')
         # request should be ajax and method should be POST.
         form = DataTransformRoot(instance=DataTransformer.objects.get(pk=request.POST['id']),
-                             data=request.POST)
+                                 data=request.POST)
         if form.is_valid():
             form.save(True)
         else:
@@ -457,7 +457,6 @@ class AccessoryViewSet(viewsets.ModelViewSet):
 
         return JsonResponse({"instance": serializer.data}, status=200)
 
-
     def postCalibration(request):
         print('post calibration')
 
@@ -604,6 +603,7 @@ class ChannelViewSet(viewsets.ModelViewSet):
                      'child_channel': Channel.objects.get(**kwargs).id,
                      'hub': Channel.objects.get(**kwargs).hub.id})
         hardware_ios = Channel.objects.get(**kwargs).hardwareio_set.all()
+        channel_stats = Channel.objects.get(**kwargs).channellstats_set.all()
 
         channel = Channel.objects.get(**kwargs)
 
@@ -611,7 +611,7 @@ class ChannelViewSet(viewsets.ModelViewSet):
         if request.accepted_renderer.format == 'html':
             return Response(
                 {"channel_form": channel_form, "channel": channel, 'hardware_io_type_form': hardware_io_type_form,
-                 'hardware_ios': hardware_ios},
+                 'hardware_ios': hardware_ios, 'channel_stats': channel_stats},
                 template_name='channel.html')
         else:
             return super(ChannelViewSet, self).retrieve()
@@ -872,3 +872,35 @@ def listHubAccessories(request, hub_id):
     serialized_accessories = AccessorySerializer(many=True).to_representation(accessories)
 
     return JsonResponse(serialized_accessories, status=200, safe=False)
+
+
+class ChannelStatsViewSet(viewsets.ModelViewSet):
+    """
+    A simple ViewSet for viewing and editing the accounts
+    associated with the user.
+    """
+    serializer_class = ChannelStatsSerializer
+
+    # permission_classes = [IsAccountAdminOrReadOnly]
+
+    def get_queryset(self):
+        return self.request.channel.channelstats_set.all()
+
+    def retrieve(self, request, *args, **kwargs):
+
+        if request.accepted_renderer.format == 'html':
+            print('retrieve')
+            print(str(request.path_info))
+            stats = ChannelStats.objects.get(**kwargs)
+            stats_form = ChannelStatsForm(instance=stats)
+
+            # accessories_form = AccessoryForm()
+            # channel_form = ChannelForm(Hub.objects.get(**kwargs).channel_set.type, instance=channel)
+            return Response(
+                {"stats_form": stats_form},
+                template_name='template_stats.html')
+        else:
+            stats = ChannelStats.objects.get(**kwargs)
+            stats_data = ChannelStatsSerializer(instance=stats).to_representation(stats)
+            return JsonResponse(stats_data, status=200)
+
